#!/bin/sh
#
# CopyLeft moon.cat
# Esta obra está bajo una licencia de Creative Commons
# http://creativecommons.org/licenses/by/3.0/deed.es
#
# Author: Rei Izumi - moon.cat - 2018
#
#
# Return codes
# 0	- Success
# 1	- Invalid arguments
# 2	- Script not found or no execution permissions
#

HTTPSERVER_PATH="/opt/IBM/HTTPServer"
START_ARGUMENTS=""
STOP_ARGUMENTS=""

servicePath="${HTTPSERVER_PATH}/bin/apachectl"
errorCode=0

ihs_start()
{
	if [ -f ${servicePath} -a -x "${servicePath}" ] ; then
		${servicePath} ${START_ARGUMENTS} start
	else
		echo "Error starting HTTP Server"
		echo "Script is not correct or is not executable: ${servicePath}"
		errorCode=2
	fi
}


ihs_stop()
{
	if [ -f ${servicePath} -a -x "${servicePath}" ] ; then
		${servicePath} ${STOP_ARGUMENTS} stop
	else
		echo "Error stopping HTTP Server"
		echo "Script is not correct or is not executable: ${servicePath}"
		errorCode=2
	fi
}

ihs_force_stop()
{
	ps axf | grep ${HTTPSERVER_PATH/bin/httpd} | grep -v grep | awk '{print "kill -9 " $1}' | sh
}

ihs_status()
{
	status=`ps -ef | grep ${HTTPSERVER_PATH/bin/httpd} | grep -v grep`
	if [ ! -z "${status}" ] ; then
		echo "HTTP Server is running"
	else
		echo "HTTP Server is not running"
	fi
}


case "$1" in
	start)
		ihs_start
	;;
	stop)
		ihs_stop
	;;
	force-stop)
		ihs_force_stop
	;;
	restart)
		ihs_stop
		ihs_start
	;;
	force-restart)
		ihs_force_stop
		ihs_start
	;;
	status)
		ihs_status
	;;
	*)
		echo "Usage: $0 {start|stop|force-stop|restart|force-restart|status}"
		errorCode=1
	;;
esac

exit $errorCode

