#!/bin/sh
#
# CopyLeft moon.cat
# Esta obra está bajo una licencia de Creative Commons
# http://creativecommons.org/licenses/by/3.0/deed.es
#
# Author: Rei Izumi - moon.cat - 2018
#
#
# Return codes
# 0	- Success
# 1	- Invalid arguments
# 2	- Script not found or no execution permissions
#

SERVER_NAME="dmgr"
PROFILE_PATH="/opt/IBM/WebSphere/AppServer/profiles/Dmgr01"
START_SCRIPT="startManager.sh"
STOP_SCRIPT="stopManager.sh"
START_ARGUMENTS=""
STOP_ARGUMENTS=""

binPath="${PROFILE_PATH}/bin"
errorCode=0

was_start()
{
	startScript="${binPath}/${START_SCRIPT}"
	if [ -f ${startScript} -a -x "${startScript}" ] ; then
		${startScript} ${START_ARGUMENTS}
	else
		echo "Error starting WebSphere Application Server - $SERVER_NAME"
		echo "Script is not correct or is not executable: ${startScript}"
		errorCode=2
	fi
}


was_stop()
{
	stopScript="${binPath}/${STOP_SCRIPT}"
	if [ -f ${stopScript} -a -x "${stopScript}" ] ; then
		${stopScript} ${STOP_ARGUMENTS}
	else
		echo "Error stopping WebSphere Application Server - $SERVER_NAME"
		echo "Script is not correct or is not executable: ${startScript}"
		errorCode=2
	fi
}

was_force_stop()
{
	ps axf | grep ${PROFILE_PATH} | grep ${SERVER_NAME} | grep -v grep | awk '{print "kill -9 " $1}' | sh
}

was_status()
{
	status=`ps -ef | grep ${PROFILE_PATH} | grep ${SERVER_NAME}`
	if [ ! -z "${status}" ] ; then
		echo "WebSphere Application Server - $SERVER_NAME is running"
	else
		echo "WebSphere Application Server - $SERVER_NAME is not running"
	fi
}


case "$1" in
	start)
		was_start
	;;
	stop)
		was_stop
	;;
	force-stop)
		was_force_stop
	;;
	restart)
		was_stop
		was_start
	;;
	force-restart)
		was_force_stop
		was_start
	;;
	status)
		was_status
	;;
	*)
		echo "Usage: $0 {start|stop|force-stop|restart|force-restart|status}"
		errorCode=1
	;;
esac

exit $errorCode
